@@ -194,6 +194,7 @@ def cache(cachename=None,
                     with db.DB.atomic():
                         store_callstack(fcall)
                         srun_fcall.stop = datetime.now()
+                        srun_fcall.success = False
                         srun_fcall.runtime = \
                             (srun_fcall.stop - srun_fcall.start)\
                             .total_seconds()
@@ -289,8 +290,7 @@ def prep_callstack(func, delete_relations=True):
                                 .order_by(-SRFC.start)\
                                 .get()
 
-            print('x' * 80, "\n", srfc)
-            if srfc.error:
+            if not srfc.success:
                 dirty = True
 
             if dirty:
