@@ -40,7 +40,7 @@ class Function(pw.Model):
         fc, created = FunctionCall.get_or_create(
             function=self, checksum=call_checksum)
         if created:
-            print(f"created new fcall {fc}")
+            lgr.debug(f"created new fcall {fc}")
             fc.dirty = True
         fc.name=name
         fc.save()
